/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/*
 * This file contains all localizable skin settings such as 
 *   font, layout, and geometry
 */
window { 
  font: 3mm tahoma,arial,helvetica,sans-serif;
}
dialog#advancedScripts {
 width: 35em !important;
}
